@@ -13,27 +13,10 @@ function mainSighupHandler() {
   });
 }
 
-function openTheStream(file, fileSize, numFiles, options) {
-  const stream = new streams.RollingFileStream(
-    file,
-    fileSize,
-    numFiles,
-    options
-  );
-  stream.on('error', (err) => {
-    console.error('log4js.fileAppender - Writing to file %s, error happened ', file, err); //eslint-disable-line
-  });
-  stream.on('drain', () => {
-    process.emit("log4js:pause", false);
-  });
-  return stream;
-}
-
-
 /**
  * File Appender writing the logs to a text file. Supports rolling of logs by size.
  *
- * @param file file log messages will be written to
+ * @param file the file log messages will be written to
  * @param layout a function that takes a logEvent and returns a string
  *   (defaults to basicLayout).
  * @param logSize - the maximum size (in bytes) for a log file,
@@ -43,48 +26,92 @@ function openTheStream(file, fileSize, numFiles, options) {
  * @param options - options to be passed to the underlying stream
  * @param timezoneOffset - optional timezone offset in minutes (default system local)
  */
-function fileAppender(file, layout, logSize, numBackups, options, timezoneOffset) {
+function fileAppender(
+  file,
+  layout,
+  logSize,
+  numBackups,
+  options,
+  timezoneOffset
+) {
+  if (typeof file !== 'string' || file.length === 0) {
+    throw new Error(`Invalid filename: ${file}`);
+  } else if (file.endsWith(path.sep)) {
+    throw new Error(`Filename is a directory: ${file}`);
+  } else {
+    // handle ~ expansion: https://github.com/nodejs/node/issues/684
+    // exclude ~ and ~filename as these can be valid files
+    file = file.replace(new RegExp(`^~(?=${path.sep}.+)`), os.homedir());
+  }
   file = path.normalize(file);
-  numBackups = (!numBackups && numBackups !== 0) ? 5 : numBackups;
+  numBackups = !numBackups && numBackups !== 0 ? 5 : numBackups;
 
   debug(
     'Creating file appender (',
-    file, ', ',
-    logSize, ', ',
-    numBackups, ', ',
-    options, ', ',
-    timezoneOffset, ')'
+    file,
+    ', ',
+    logSize,
+    ', ',
+    numBackups,
+    ', ',
+    options,
+    ', ',
+    timezoneOffset,
+    ')'
   );
 
+  function openTheStream(filePath, fileSize, numFiles, opt) {
+    const stream = new streams.RollingFileStream(
+      filePath,
+      fileSize,
+      numFiles,
+      opt
+    );
+    stream.on('error', (err) => {
+      // eslint-disable-next-line no-console
+      console.error(
+        'log4js.fileAppender - Writing to file %s, error happened ',
+        filePath,
+        err
+      );
+    });
+    stream.on('drain', () => {
+      process.emit('log4js:pause', false);
+    });
+    return stream;
+  }
+
   let writer = openTheStream(file, logSize, numBackups, options);
 
-  const app = function (loggingEvent) {
+  const app = function(loggingEvent) {
     if (!writer.writable) {
       return;
     }
     if (options.removeColor === true) {
       // eslint-disable-next-line no-control-regex
       const regex = /\x1b[[0-9;]*m/g;
-      loggingEvent.data = loggingEvent.data.map(d => {
+      loggingEvent.data = loggingEvent.data.map((d) => {
         if (typeof d === 'string') return d.replace(regex, '');
         return d;
       });
     }
-    if (!writer.write(layout(loggingEvent, timezoneOffset) + eol, "utf8")) {
+    if (!writer.write(layout(loggingEvent, timezoneOffset) + eol, 'utf8')) {
       process.emit('log4js:pause', true);
     }
   };
 
-  app.reopen = function () {
-    writer.end(() => { writer = openTheStream(file, logSize, numBackups, options); });
+  app.reopen = function() {
+    writer.end(() => {
+      writer = openTheStream(file, logSize, numBackups, options);
+    });
   };
 
-  app.sighupHandler = function () {
+  app.sighupHandler = function() {
     debug('SIGHUP handler called.');
     app.reopen();
   };
 
-  app.shutdown = function (complete) {
+  app.shutdown = function(complete) {
     sighupListeners.delete(app);
     if (sighupListeners.size === 0 && mainSighupListenerStarted) {
       process.removeListener('SIGHUP', mainSighupHandler);
